% "" h=250 .   m=0.010 . Rho [kg/m3]
%settings
glass=zeros(250,50); %reservoir size of 250x50 px

%environment, gravity
g=9.81;         %gravity constant

%fluid init
w_Rho=1000;     %density of fluid

%pellet initial state and position
p_Rho=11000; %density
p_xy=[25 1]; %coordinates
p_sp=0;      %initian speed   
p_sz=2E-3;   %size   
p_m=0.050;   %mass   
p_V=p_m/p_Rho; %volume

%%%
%action
imshow(glass); %output on start

%%%
%data logging
sec_x=[]; %arrays for pellet state logging
speed_y=[];
deep_y=[];

%2 forces act in that model
%Fp=mg  Fa=Rho_g_V - gravity and Archimedes forces description
Fp=p_m*g;
Fa=w_Rho*g*p_V;
delta_F=Fa-Fp; %<0 sinks, >0 floats 
p_a=abs(delta_F)/p_m; %pellet's acceleration, nonzero, abs(delta_F)  
t=0.1; %discretisation of time in experiment 0.1 second
size_glass=size(glass); %reservoirs height and width

for i=1:100 %100 falling of 100 frames max
 p_sp=p_sp+p_a*t; %speed acceleration
 dS=p_sp*t;  %speed delta
 
 if (delta_F<0) %pellet sinks, because Fa<Fg
 p_xy=p_xy+[0 round(dS)]; %enlarge depth
 end;
 
 if (delta_F>0) %pellet sinks, because Fa<Fg
     disp('Pellet is floating!)
 
 
 if p_xy(2)>size_glass(1) %checking of bottom reaching
     disp ('bottom is reached'); 
     break; %break up the cycle in that case
 end;
 
 %preparation of animated frame before output 
 pict_out=glass;
 pict_out(p_xy(2),p_xy(1))=1;
 
 %changing frame in visual picture
 imagesc(pict_out);
 
 %data logging
 sec_x=[sec_x (i*t)];
 speed_y=[speed_y p_sp];
 deep_y=[deep_y p_xy(2)];
 %pict heading
 heading=strcat('Frame ' num2str(i),' of 100; ', 'T [sec] =', num2str((i*t)));
 title(heading);
 pause (1);
end;

%final graphics output
figure;
subplot(2,1,1); 
plot(sec_x,speed_y);
title ('Speed changes with time');
xlabel('x, time, s');
ylabel('V(x), speed, [m/s]');
subplot(2,1,2); 
plot(sec_x,deep_y);
title ('Deep changes with time');
xlabel('x, time [s]');
ylabel('h(x), deep [m]');
